@@ -28,30 +28,25 @@ RemoveGaps <- function(myXStringSet,
 	if (!is.null(processors) && processors < 1)
 		stop("processors must be at least 1.")
 	if (is.null(processors)) {
-		processors <- .detectCores()
+		processors <- .Call("detectCores", PACKAGE="DECIPHER")
 	} else {
 		processors <- as.integer(processors)
 	}
 	
 	if (removeGaps == 2L) { # all gaps
-		ns <- names(myXStringSet)
-		myXStringSet <- .Call("removeGaps",
-			myXStringSet,
-			type,
-			includeMask,
-			processors,
-			PACKAGE="DECIPHER")
-		names(myXStringSet) <- ns
+		functionCall <- "removeGaps"
 	} else if (removeGaps == 3L) { # common gaps
-		ns <- names(myXStringSet)
-		myXStringSet <- .Call("removeCommonGaps",
-			myXStringSet,
-			type,
-			includeMask,
-			processors,
-			PACKAGE="DECIPHER")
-		names(myXStringSet) <- ns
+		functionCall <- "removeCommonGaps"
 	}
 	
+	ns <- names(myXStringSet)
+	myXStringSet <- .Call(functionCall,
+		myXStringSet,
+		type,
+		includeMask,
+		processors,
+		PACKAGE="DECIPHER")
+	names(myXStringSet) <- ns
+	
 	return(myXStringSet)
 }
